==> snipe-it-6.3.0.zip: snipe-it-6.3.0/resources/lang/fil-PH/admin/hardware/form.php <==
<?php

return [
    'bulk_delete'		=> 'I-kumperma ang Maramihang Pagdelete ng mga Assets',
    'bulk_restore'      => 'Confirm Bulk Restore Assets', 
  'bulk_delete_help'	=> 'Surrin ang mga asset para sa maramihing pagdelete sa ibaba. Kapag nai-delete na, ang mga asset na ito ay pwedeng maibalik sa dati, pero hindi na ito maiugnay sa kahit sinong user na nakatalaga nito.',
  'bulk_restore_help'	=> 'Review the assets for bulk restoration below. Once restored, these assets will not be associated with any users they were previously assigned to.',
  'bulk_delete_warn'	=> 'Ikaw ay mag-delete ng :asset_count na mga asset.',
  'bulk_restore_warn'	=> 'You are about to restore :asset_count assets.',
    'bulk_update'		=> 'Ang Maramihang Asset na Nai-update',
    'bulk_update_help'	=> 'Ang form na ito ay nagbibigay sa iyo ng pahintulot para mag-update ng maramihang asset nang sabay-sabay. Lagyan lamang ang mga field na gusto mong baguhin. Anumang mga field na blangko ay mananatiling walang pagbabago. ',
    'bulk_update_warn'	=> 'You are about to edit the properties of a single asset.|You are about to edit the properties of :asset_count assets.',
    'bulk_update_with_custom_field' => 'Note the assets are :asset_model_count different types of models.',
    'bulk_update_model_prefix' => 'On Models', 
    'bulk_update_custom_field_unique' => 'This is a unique field and can not be bulk edited.',
    'checkedout_to'		=> 'I-check Out Sa',
    'checkout_date'		=> 'Ang Petsa ng Pagcheck-out',
    'checkin_date'		=> 'Ang Petsa ng Pag-checkin',
    'checkout_to'		=> 'Mag-check out sa',
    'cost'				=> 'Ang Halaga ng Pagbili',
    'create'			=> 'Magsagawa ng Asset',
    'date'				=> 'Ang Petsa ng Pagbili',
    'depreciation'	    => 'Ang Depresasyon',
    'depreciates_on'	=> 'Ma-depreciate Sa',
    'default_location'	=> 'I-default ang Lakasyon',
    'default_location_phone' => 'Default Location Phone',
    'eol_date'			=> 'Ang Petsa ng EOL',
    'eol_rate'			=> 'Ang Halaga ng EOL',
    'expected_checkin'  => 'Ang Inaasahang Petsa ng Pag-checkin',
    'expires'			=> 'Mawalan ng Bisa',
    'fully_depreciated'	=> 'Ganap nang Na-depreciate',
    'help_checkout'		=> 'Kung nais mong italaga ang asset na ito sa madaling panahon, piliin ang "Ready to Deploy" mula sa listahan ng katangian sa itaas. ',
    'mac_address'		=> 'Ang MAC address',
    'manufacturer'		=> 'Ang Tagapagsagawa',
    'model'				=> 'Ang modelo',
    'months'			=> 'mga buwan',
    'name'				=> 'Ang Pangalan ng Asset',
    'notes'				=> 'Ang mga Palatandaan',
    'order'				=> 'Ang Numero ng Order',
    'qr'				=> 'Ang Code ng QR',
    'requestable'		=> 'Ang mga gumagamit ay pwedeng mag-rekwest ng asset na ito',
    'select_statustype'	=> 'Pumili ng Tipo ng Katayuan',
    'serial'			=> 'Ang Seryal',
    'status'			=> 'Ang Katayuan',
    'tag'				=> 'Ang Tag ng Asset',
    'update'			=> 'Ang Update sa Asset',
    'warranty'			=> 'Ang Warantiya',
        'warranty_expires'		=> 'Nag-expire na ang Warantiya',
    'years'				=> 'mga taon',
    'asset_location' => 'Update Asset Location',
    'asset_location_update_default_current' => 'Update default location AND actual location',
    'asset_location_update_default' => 'Update only default location',
    'asset_location_update_actual' => 'Update only actual location',
    'asset_not_deployable' => 'That asset status is not deployable. This asset cannot be checked out.',
    'asset_deployable' => 'That status is deployable. This asset can be checked out.',
    'processing_spinner' => 'Processing... (This might take a bit of time on large files)',
    'optional_infos'  => 'Optional Information',
    'order_details'   => 'Order Related Information'
];

==> snipe-it-7.0.11.zip: snipe-it-7.0.11/resources/lang/fil-PH/admin/hardware/form.php <==
<?php

return [
    'bulk_delete'		=> 'I-kumperma ang Maramihang Pagdelete ng mga Assets',
    'bulk_restore'      => 'Confirm Bulk Restore Assets', 
  'bulk_delete_help'	=> 'Surrin ang mga asset para sa maramihing pagdelete sa ibaba. Kapag nai-delete na, ang mga asset na ito ay pwedeng maibalik sa dati, pero hindi na ito maiugnay sa kahit sinong user na nakatalaga nito.',
  'bulk_restore_help'	=> 'Review the assets for bulk restoration below. Once restored, these assets will not be associated with any users they were previously assigned to.',
  'bulk_delete_warn'	=> 'Ikaw ay mag-delete ng :asset_count na mga asset.',
  'bulk_restore_warn'	=> 'You are about to restore :asset_count assets.',
    'bulk_update'		=> 'Ang Maramihang Asset na Nai-update',
    'bulk_update_help'	=> 'Ang form na ito ay nagbibigay sa iyo ng pahintulot para mag-update ng maramihang asset nang sabay-sabay. Lagyan lamang ang mga field na gusto mong baguhin. Anumang mga field na blangko ay mananatiling walang pagbabago. ',
    'bulk_update_warn'	=> 'You are about to edit the properties of a single asset.|You are about to edit the properties of :asset_count assets.',
    'bulk_update_with_custom_field' => 'Note the assets are :asset_model_count different types of models.',
    'bulk_update_model_prefix' => 'On Models', 
    'bulk_update_custom_field_unique' => 'This is a unique field and can not be bulk edited.',
    'checkedout_to'		=> 'I-check Out Sa',
    'checkout_date'		=> 'Ang Petsa ng Pagcheck-out',
    'checkin_date'		=> 'Ang Petsa ng Pag-checkin',
    'checkout_to'		=> 'Mag-check out sa',
    'cost'				=> 'Ang Halaga ng Pagbili',
    'create'			=> 'Magsagawa ng Asset',
    'date'				=> 'Ang Petsa ng Pagbili',
    'depreciation'	    => 'Ang Depresasyon',
    'depreciates_on'	=> 'Ma-depreciate Sa',
    'default_location'	=> 'I-default ang Lakasyon',
    'default_location_phone' => 'Default Location Phone',
    'eol_date'			=> 'Ang Petsa ng EOL',
    'eol_rate'			=> 'Ang Halaga ng EOL',
    'expected_checkin'  => 'Ang Inaasahang Petsa ng Pag-checkin',
    'expires'			=> 'Mawalan ng Bisa',
    'fully_depreciated'	=> 'Ganap nang Na-depreciate',
    'help_checkout'		=> 'Kung nais mong italaga ang asset na ito sa madaling panahon, piliin ang "Ready to Deploy" mula sa listahan ng katangian sa itaas. ',
    'mac_address'		=> 'Ang MAC address',
    'manufacturer'		=> 'Ang Tagapagsagawa',
    'model'				=> 'Ang modelo',
    'months'			=> 'mga buwan',
    'name'				=> 'Ang Pangalan ng Asset',
    'notes'				=> 'Ang mga Palatandaan',
    'order'				=> 'Ang Numero ng Order',
    'qr'				=> 'Ang Code ng QR',
    'requestable'		=> 'Ang mga gumagamit ay pwedeng mag-rekwest ng asset na ito',
    'redirect_to_all'   => 'Return to all :type',
    'redirect_to_type'   => 'Go to :type',
    'redirect_to_checked_out_to'   => 'Go to Checked Out to',
    'select_statustype'	=> 'Pumili ng Tipo ng Katayuan',
    'serial'			=> 'Ang Seryal',
    'status'			=> 'Ang Katayuan',
    'tag'				=> 'Ang Tag ng Asset',
    'update'			=> 'Ang Update sa Asset',
    'warranty'			=> 'Ang Warantiya',
        'warranty_expires'		=> 'Nag-expire na ang Warantiya',
    'years'				=> 'mga taon',
    'asset_location' => 'Update Asset Location',
    'asset_location_update_default_current' => 'Update default location AND actual location',
    'asset_location_update_default' => 'Update only default location',
    'asset_location_update_actual' => 'Update only actual location',
    'asset_not_deployable' => 'That asset status is not deployable. This asset cannot be checked out.',
    'asset_deployable' => 'That status is deployable. This asset can be checked out.',
    'processing_spinner' => 'Processing... (This might take a bit of time on large files)',
    'optional_infos'  => 'Optional Information',
    'order_details'   => 'Order Related Information'
];
